@@ -1,7 +1,6 @@
 import sys
 import numpy
 from PyQt5.QtWidgets import QApplication, QMessageBox, QSizePolicy
-from PyQt5.QtGui import QIntValidator, QDoubleValidator
 
 from orangewidget import gui
 from orangewidget.settings import Setting
@@ -62,7 +61,7 @@ class Transfocator(XoppyWidget):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "NUMBER_LENS",
                                        label=self.unitLabels()[idx], addSpace=False,
-                                       valueType=int, validator=QDoubleValidator(),  orientation="horizontal", labelWidth=150)
+                                       valueType=int,  orientation="horizontal", labelWidth=150)
         self.show_at(self.unitFlags()[idx], box1)
 
         # widget index 3
@@ -77,7 +76,7 @@ class Transfocator(XoppyWidget):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "THICK",
                                        label=self.unitLabels()[idx], addSpace=False,
-                                       valueType=float, validator=QDoubleValidator(),  orientation="horizontal", labelWidth=150)
+                                       valueType=float,  orientation="horizontal", labelWidth=150)
         self.show_at(self.unitFlags()[idx], box1)
 
         # widget index 5
@@ -85,7 +84,7 @@ class Transfocator(XoppyWidget):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "DENS",
                           label=self.unitLabels()[idx], addSpace=False,
-                          valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=150)
+                          valueType=float, orientation="horizontal", labelWidth=150)
         self.show_at(self.unitFlags()[idx], box1)
 
         # widget index 6
@@ -93,7 +92,7 @@ class Transfocator(XoppyWidget):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "ENER_MIN",
                           label=self.unitLabels()[idx], addSpace=False,
-                          valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                          valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         # widget index 7
@@ -101,7 +100,7 @@ class Transfocator(XoppyWidget):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "ENER_MAX",
                           label=self.unitLabels()[idx], addSpace=False,
-                          valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                          valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         # widget index 8
@@ -109,7 +108,7 @@ class Transfocator(XoppyWidget):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "ENER_N",
                           label=self.unitLabels()[idx], addSpace=False,
-                          valueType=int, validator=QIntValidator(), orientation="horizontal", labelWidth=250)
+                          valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         # widget index 9 ***********   File Browser ******************
